==> Mk2_201b.zip: var/local/www/setclocktime.php <==
<?php session_start();                                                                                                              
  header ("HTTP/1.1 200 OK");
  include 'tcfunctions.php';      
  if ($_POST["action"] == "Set Time"){
      unset($return_str);
      unset($return_var);
      unset($return_str1);
      unset($return_var1);
      $unixsetclockdatetime2 = string2date(0, 0, 0, 0, $_POST["currentdate"], formatstr2sec($_POST["currenttime"], 0, 0));
      $newclocktime = date("mdHiY"."."."s", $unixsetclockdatetime2);
      if ($_SESSION["iammodel"] == 1){
          $return_var = systemcmd_ex("date " .$newclocktime);
          //exec("/sbin/hwclock -w -u", $return_str1, $return_var1);
      }
      if ($_SESSION["iammodel"] == 2){          
          exec("date " .trim($newclocktime), $return_str, $return_var);
          //exec("/sbin/hwclock -w -u", $return_str1, $return_var1); Nee something else here.          
      }
      if ($return_var <> 0){
          $result = "<p class=\"error center\">Setting the clock time has failed</p>";
      } else {
          $conn = connect();
          $sql = "update thisdev set refreshdb = 128;";
          dbaction($conn,$sql,false);
          $result = "<p class=\"success center\">The clock time has been set</p>";
      }
  }   
?>

<html>
<head>
<?php htmlheadercontent(); ?>
</head>
<?php    
    bodyhtmlheader();
    if($_SESSION["logged_in"] == true){
    editrec($recid);
    }
    bodyhtmlfooter();
?>
</html>

<?php function editrec()
{   
  global $result;
?>
<div class="centerform"> 
    <?php
        formhtmlheader('Update Clock Date and Time') ?>            
            <form enctype="multipart/form-data" action="setclocktime.php" method="post">            
            <table class="tbl" border="0" cellspacing="1" cellpadding="5">
                <tr>
                    <td colspan="2"><?php echo $result ?></td>                    
                </tr>                                       
                <tr>
                    <td class="hr"><?php echo htmlspecialchars("Time")."&nbsp;" ?></td>
                    <td class="dr"><input class="il3" type="text" name="currenttime" value="<?php echo date("H:i:s"); ?>"></td>
                </tr>
                <tr>
                    <td class="hr"><?php echo htmlspecialchars("Date")."&nbsp;" ?></td>
                    <td class="dr"><input  class="il3" type="text" name="currentdate" value="<?php echo date($_SESSION["dateformatpic"]) ?>"></td>
                </tr> 
            </table>
            <br>
            <table align="center">
                <tr>
                    <td>                    
                        <input type="submit" name="action" value="Set Time" class="normalbutton">                                        
                        <input type="button" value="Cancel" onclick="window.location='setclocktime.php'" class="normalbutton">                                        
                    </td>
                </tr>
            </table>                      
            </form>
        <?php formhtmlfooter() ?> 
    <?php } ?>
</div>

==> Mk2_204b.zip: var/local/www/setclocktime.php <==
<?php session_start();                                                                                                              
  header ("HTTP/1.1 200 OK");
  include 'tcfunctions.php';      
  setlanguage();
  if ($_POST["action"] == "Set Time"){
      unset($return_str);
      unset($return_var);
      unset($return_str1);
      unset($return_var1);
      $unixsetclockdatetime2 = string2date(0, 0, 0, 0, $_POST["currentdate"], formatstr2sec($_POST["currenttime"], 0, 0));
      $newclocktime = date("mdHiY"."."."s", $unixsetclockdatetime2);
      if ($_SESSION["iammodel"] == 1){
          $return_var = systemcmd_ex("date " .$newclocktime);
          //exec("/sbin/hwclock -w -u", $return_str1, $return_var1);
      }
      if ($_SESSION["iammodel"] == 2){          
          exec("date " .trim($newclocktime), $return_str, $return_var);
          //exec("/sbin/hwclock -w -u", $return_str1, $return_var1); Nee something else here.          
      }
      if ($return_var <> 0){
          $result = "<p class=\"error center\">Setting the clock time has failed</p>";
      } else {
          $conn = connect();
          $sql = "update thisdev set refreshdb = 128;";
          dbaction($conn,$sql,false);
          $result = "<p class=\"success center\">The clock time has been set</p>";
      }
  }   
?>

<html>
<head>
<?php htmlheadercontent(); ?>
</head>
<?php    
    bodyhtmlheader();
    if($_SESSION["logged_in"] == true){
    editrec($recid);
    }
    bodyhtmlfooter();
?>
</html>

<?php function editrec()
{   
  global $result;
?>
<div class="centerform"> 
    <?php
        formhtmlheader('Update Clock Date and Time') ?>            
            <form enctype="multipart/form-data" action="setclocktime.php" method="post">            
            <table class="tbl" border="0" cellspacing="1" cellpadding="5">
                <tr>
                    <td colspan="2"><?php echo $result ?></td>                    
                </tr>                                       
                <tr>
                    <td class="hr"><?php echo htmlspecialchars("Time")."&nbsp;" ?></td>
                    <td class="dr"><input class="il3" type="text" name="currenttime" value="<?php echo date("H:i:s"); ?>"></td>
                </tr>
                <tr>
                    <td class="hr"><?php echo htmlspecialchars("Date")."&nbsp;" ?></td>
                    <td class="dr"><input  class="il3" type="text" name="currentdate" value="<?php echo date($_SESSION["dateformatpic"]) ?>"></td>
                </tr> 
            </table>
            <br>
            <table align="center">
                <tr>
                    <td>                    
                        <input type="submit" name="action" value="Set Time" class="normalbutton">                                        
                        <input type="button" value="<?php echo $_SESSION["Cancel"] ?>" onclick="window.location='setclocktime.php'" class="normalbutton">                                        
                    </td>
                </tr>
            </table>                      
            </form>
        <?php formhtmlfooter() ?> 
    <?php } ?>
</div>
